@@ -2,12 +2,12 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_ALGORITHM_MINKOWSKISUM_H_
-#define _SFCGAL_ALGORITHM_MINKOWSKISUM_H_
+#ifndef SFCGAL_ALGORITHM_MINKOWSKISUM_H_
+#define SFCGAL_ALGORITHM_MINKOWSKISUM_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/Geometry.h>
+#include "SFCGAL/Geometry.h"
 #include <memory>
 
 namespace SFCGAL {
@@ -23,7 +23,6 @@ struct NoValidityCheck;
  *
  * @todo missing cases (union)
  * @pre gA and gB are valid geometries
- * @ingroup public_api
  */
 SFCGAL_API std::unique_ptr<Geometry>
            minkowskiSum(const Geometry &gA, const Polygon &gB);
@@ -37,7 +36,6 @@ SFCGAL_API std::unique_ptr<Geometry>
  *
  * @todo missing cases (union)
  * @pre gA and gB are valid geometries
- * @ingroup detail
  * @warning@ No actual validity check is done.
  */
 SFCGAL_API std::unique_ptr<Geometry>
